@@ -29,7 +29,7 @@ from xml.dom import Node
 
 from opendocument import load
 
-from namespaces import ANIMNS, CHARTNS, CONFIGNS, DCNS, DR3DNS, DRAWNS, FONS, \
+from odf.namespaces import ANIMNS, CHARTNS, CONFIGNS, DCNS, DR3DNS, DRAWNS, FONS, \
   FORMNS, MATHNS, METANS, NUMBERNS, OFFICENS, PRESENTATIONNS, SCRIPTNS, \
   SMILNS, STYLENS, SVGNS, TABLENS, TEXTNS, XLINKNS
 
@@ -748,12 +748,15 @@ class ODF2XHTML(handler.ContentHandler):
         """
         objhref = attrs[(XLINKNS,"href")]
         # Remove leading "./": from "./Object 1" to "Object 1"
-#       objhref = objhref [2:]
+        # objhref = objhref [2:]
        
         # Not using os.path.join since it fails to find the file on Windows.
-#       objcontentpath = '/'.join([objhref, 'content.xml'])
-
-        for c in self.document.childnodes:
+        # objcontentpath = '/'.join([objhref, 'content.xml'])
+        ################################
+        # fixed: self.document.childnodes ===>  self.document.childobjects
+        # 2016-02-19 G.K.
+        ################################
+        for c in self.document.childobjects:
             if c.folder == objhref:
                 self._walknode(c.topnode)
 
@@ -1442,10 +1445,7 @@ ol, ul { padding-left: 2em; }
 
         self.lines = []
         self._wfunc = self._wlines
-        if type(odffile)==type(u""):
-            self.document = load(odffile)
-        else:
-            self.document = odffile
+        self.document = load(odffile)
         self._walknode(self.document.topnode)
 
     def _walknode(self, node):
